@@ -10,10 +10,12 @@ def index():
 
 @app.route('/tags')
 def tags():
-    return render_template('index.html', projects=api.get_projects(
-        request.args.get('q'),
-        opts=request.args
-    ))
+    projects = api.get_projects(request.args.get('q'), opts=request.args)
+    refresh_tags_time = api.get_refresh_tags_time()
+    if request.args.get('format') == 'json':
+        return {'refresh_tags_time': refresh_tags_time, 'results': projects}
+    else:
+        return render_template('index.html', projects=projects, refresh_tags_time=refresh_tags_time)
 
 
 @app.route('/reset')
@@ -31,13 +33,17 @@ def refresh_tags():
 @app.route('/search')
 def search():
     if 'search' in request.args and 'filepath' in request.args and 'ref' in request.args:
-        return render_template('search.html', results=api.search(
+        results = api.search(
             request.args['search'],
             request.args['filepath'],
             request.args['ref'],
             project_search=request.args.get('q'),
             project_opts=request.args
-        ))
+        )
+        if request.args.get('format') == 'json':
+            return {'results': results}
+        else:
+            return render_template('search.html', results=results)
     else:
         return render_template('search.html')
 
